@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Tuple
 
 from paramak import ExtrudeCircleShape
 
@@ -24,11 +24,11 @@ class PortCutterCircular(ExtrudeCircleShape):
         self,
         radius: float,
         distance: float,
-        center_point: Optional[tuple] = (0, 0),
-        workplane: Optional[str] = "ZY",
-        rotation_axis: Optional[str] = "Z",
-        extrusion_start_offset: Optional[float] = 1.0,
-        name: Optional[str] = "circular_port_cutter",
+        center_point: Tuple[float, float] = (0, 0),
+        workplane: str = "ZY",
+        rotation_axis: str = "Z",
+        extrusion_start_offset: float = 1.0,
+        name: str = "circular_port_cutter",
         **kwargs
     ):
         super().__init__(
