@@ -7,7 +7,6 @@ from shutil import copymode, move
 from tempfile import mkstemp
 from typing import List, Optional, Tuple, Union
 
-import tempfile
 import cadquery as cq
 import numpy as np
 import plotly.graph_objects as go
@@ -17,6 +16,46 @@ from cadquery.occ_impl import shapes
 import OCP
 
 
+def export_solids_to_brep_object(
+    solids: Iterable,
+):
+    """Returns a brep object from a iterable of solids with merged surfaces.
+
+    Args:
+        solids: a list of cadquery solids
+
+    Returns:
+        brep cadquery object
+    """
+
+    # TODO bring non merge capability back
+    # if not merge:
+    #     geometry_to_save = cq.Compound.makeCompound([self.solid, self.graveyard.solid.val()])
+    #     geometry_to_save.exportBrep(str(path_filename))
+
+    bldr = OCP.BOPAlgo.BOPAlgo_Splitter()
+
+    if len(solids) == 1:
+        return solids[0].val()
+
+    for solid in solids:
+        # checks if solid is a compound as .val() is not needed for compounds
+        if isinstance(solid, cq.occ_impl.shapes.Compound):
+            bldr.AddArgument(solid.wrapped)
+        else:
+            bldr.AddArgument(solid.val().wrapped)
+
+    bldr.SetNonDestructive(True)
+
+    bldr.Perform()
+
+    bldr.Images()
+
+    merged_solid = cq.Compound(bldr.Shape())
+
+    return merged_solid
+
+
 def export_solids_to_brep(
     solids: Iterable,
     filename: str = "reactor.brep",
@@ -39,31 +78,7 @@ def export_solids_to_brep(
 
     path_filename.parents[0].mkdir(parents=True, exist_ok=True)
 
-    # TODO bring non merge capability back
-    # if not merge:
-    #     geometry_to_save = cq.Compound.makeCompound([self.solid, self.graveyard.solid.val()])
-    #     geometry_to_save.exportBrep(str(path_filename))
-
-    bldr = OCP.BOPAlgo.BOPAlgo_Splitter()
-
-    if len(solids) == 1:
-        solids[0].val().exportBrep(str(path_filename))
-        return str(path_filename)
-
-    for solid in solids:
-        # checks if solid is a compound as .val() is not needed for compounds
-        if isinstance(solid, cq.occ_impl.shapes.Compound):
-            bldr.AddArgument(solid.wrapped)
-        else:
-            bldr.AddArgument(solid.val().wrapped)
-
-    bldr.SetNonDestructive(True)
-
-    bldr.Perform()
-
-    bldr.Images()
-
-    merged_solid = cq.Compound(bldr.Shape())
+    merged_solid = export_solids_to_brep_object(solids)
 
     merged_solid.exportBrep(str(path_filename))
 
@@ -81,6 +96,9 @@ def export_solids_to_dagmc_h5m(
     bounding_box_atol: float = 0.000001,
     tags: List[str] = None,
 ):
+    if verbose:
+        print("solids", solids, "\n")
+        print("tags", tags, "\n")
     if len(tags) != len(solids):
         msg = (
             "When specifying tags then there must be one tag for "
@@ -89,45 +107,43 @@ def export_solids_to_dagmc_h5m(
         )
         raise ValueError(msg)
 
-    # a local import is used here as these packages need Moab to work
-    from brep_to_h5m import brep_to_h5m
-    import brep_part_finder as bpf
-
-    tmp_brep_filename = tempfile.mkstemp(suffix=".brep", prefix="paramak_")[1]
-
-    # saves the reactor as a Brep file with merged surfaces
-    export_solids_to_brep(solids=solids, filename=tmp_brep_filename)
-
-    # brep file is imported
-    brep_file_part_properties = bpf.get_brep_part_properties(tmp_brep_filename)
+    compound_expanded_tags = []
+    # solids could contain compounds
+    for tag, solid in zip(tags, solids):
+        # before accessing the .val() check it exists
+        if hasattr(solid, "val"):
+            # if it is a compound then we need more material tags
+            if isinstance(solid.val(), cq.occ_impl.shapes.Compound):
+                additional_tags = [tag] * len(solid.val().Solids())
+                compound_expanded_tags = compound_expanded_tags + additional_tags
+            else:
+                compound_expanded_tags.append(tag)
+            # if it is a compound then we need more material tags
+        elif isinstance(solid, cq.occ_impl.shapes.Compound):
+            additional_tags = [tag] * len(solid.Solids())
+            compound_expanded_tags = compound_expanded_tags + additional_tags
+        else:
+            compound_expanded_tags.append(tag)
 
     if verbose:
-        print("brep_file_part_properties", brep_file_part_properties)
+        print("compound_expanded_tags", compound_expanded_tags, "\n")
 
-    shape_properties = {}
-    for counter, solid in enumerate(solids):
-        sub_solid_descriptions = []
+    # a local import is used here as these packages need Moab to work
+    from brep_to_h5m import mesh_brep, mesh_to_h5m_in_memory_method
+    import brep_part_finder as bpf
 
-        # checks if the solid is a cq.Compound or not
-        if isinstance(solid, cq.occ_impl.shapes.Compound):
-            iterable_solids = solid.Solids()
-        else:
-            iterable_solids = solid.val().Solids()
+    # saves the reactor as a Brep file with merged surfaces
+    brep_shape = export_solids_to_brep_object(solids=solids)
 
-        for sub_solid in iterable_solids:
-            part_bb = sub_solid.BoundingBox()
-            part_center = sub_solid.Center()
-            sub_solid_description = {
-                "volume": sub_solid.Volume(),
-                "center": (part_center.x, part_center.y, part_center.z),
-                "bounding_box": (
-                    (part_bb.xmin, part_bb.ymin, part_bb.zmin),
-                    (part_bb.xmax, part_bb.ymax, part_bb.zmax),
-                ),
-            }
-            sub_solid_descriptions.append(sub_solid_description)
+    brep_file_part_properties = bpf.get_part_properties_from_shapes(brep_shape)
 
-            shape_properties[tags[counter]] = sub_solid_descriptions
+    if verbose:
+        print("brep_file_part_properties", brep_file_part_properties, "\n")
+
+    shape_properties = bpf.get_part_properties_from_shapes(solids)
+    # for counter, solid in enumerate(solids):
+
+    #     shape_properties[counter] = bpf.get_part_properties_from_shape(solid)
 
     if verbose:
         print("shape_properties", shape_properties)
@@ -136,30 +152,51 @@ def export_solids_to_dagmc_h5m(
     # using the volume, center, bounding box that we know about when creating the
     # CAD geometry in the first place
 
-    key_and_part_id = bpf.get_dict_of_part_ids(
+    brep_and_shape_part_ids = bpf.get_matching_part_ids(
         brep_part_properties=brep_file_part_properties,
         shape_properties=shape_properties,
         volume_atol=volume_atol,
         center_atol=center_atol,
         bounding_box_atol=bounding_box_atol,
     )
+    if verbose:
+        print(f"brep_and_shape_part_ids={brep_and_shape_part_ids}")
+
+    material_tags_in_brep_order = []
+    for (brep_id, shape_id) in brep_and_shape_part_ids:
+        material_tags_in_brep_order.append(compound_expanded_tags[shape_id - 1])
 
     if verbose:
-        print(f"key_and_part_id={key_and_part_id}")
+        print(f"material_tags_in_brep_order={material_tags_in_brep_order}")
 
-    brep_to_h5m(
+    # gmsh requires an actual brep file to load
+    tmp_brep_filename = mkstemp(suffix=".brep", prefix="paramak_")[1]
+    brep_shape.exportBrep(tmp_brep_filename)
+
+    gmsh, volumes = mesh_brep(
         brep_filename=tmp_brep_filename,
-        volumes_with_tags=key_and_part_id,
-        h5m_filename=filename,
         min_mesh_size=min_mesh_size,
         max_mesh_size=max_mesh_size,
-        delete_intermediate_stl_files=True,
     )
 
-    # temporary brep is deleted using os.remove
-    remove(tmp_brep_filename)
+    if verbose:
+        gmsh_filename = mkstemp(suffix=".msh", prefix="paramak_")[1]
+        print(f"written gmsh file to {gmsh_filename}")
+        gmsh.write(gmsh_filename)
 
-    return filename
+    h5m_filename = mesh_to_h5m_in_memory_method(
+        volumes=volumes,
+        material_tags=material_tags_in_brep_order,
+        h5m_filename=filename,
+    )
+
+    if verbose:
+        print(f"written brep file to {tmp_brep_filename}")
+    else:
+        # temporary brep is deleted using os.remove
+        remove(tmp_brep_filename)
+
+    return h5m_filename
 
 
 def get_bounding_box(solid) -> Tuple[Tuple[float, float, float], Tuple[float, float, float]]:
